@@ -5,7 +5,7 @@ from processor.template_processor.terraform_template_processor import TerraformT
 from processor.template_processor.kubernetes_template_processor import KubernetesTemplateProcessor
 from processor.template_processor.yaml_template_processor import YamlTemplateProcessor
 from processor.template_processor.json_template_processor import JsonTemplateProcessor
-
+from processor.template_processor.helm_chart_template_processor import HelmChartTemplateProcessor
 TEMPLATE_NODE_TYPES = {
     "cloudformation": AWSTemplateProcessor,
     "arm" : AzureTemplateProcessor,
@@ -13,5 +13,6 @@ TEMPLATE_NODE_TYPES = {
     "terraform" : TerraformTemplateProcessor,
     "kubernetesObjectFiles" : KubernetesTemplateProcessor,
     "yaml" : YamlTemplateProcessor,
-    "json": JsonTemplateProcessor
+    "json": JsonTemplateProcessor,
+    "helmChart" : HelmChartTemplateProcessor
 }
\ No newline at end of file
